Struct augdom::event::AnimationCancel [−][src]
pub struct AnimationCancel(_);Expand description
A CSS animation has aborted. MDN documentation
Methods from Deref<Target = AnimationEvent>
Getter for the animationName field of this object.
This API requires the following crate features to be activated: AnimationEvent
Getter for the elapsedTime field of this object.
This API requires the following crate features to be activated: AnimationEvent
Getter for the pseudoElement field of this object.
This API requires the following crate features to be activated: AnimationEvent