Struct augdom::event::AnimationEndBuilder [−][src]
pub struct AnimationEndBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = AnimationEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: AnimationEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: AnimationEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: AnimationEventInit
Change the animationName field of this object.
This API requires the following crate features to be activated: AnimationEventInit
Change the elapsedTime field of this object.
This API requires the following crate features to be activated: AnimationEventInit
Change the pseudoElement field of this object.
This API requires the following crate features to be activated: AnimationEventInit