pub struct AudioEndedBuilder(_);
Change the bubbles field of this object.
This API requires the following crate features to be activated: EventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: EventInit
Change the composed field of this object.
This API requires the following crate features to be activated: EventInit
Returns the “default value” for a type. Read more
The resulting type after dereferencing.
Mutably dereferences the value.
The event produced by the builder.
Build, returning the output.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.