Struct augdom::event::ChildMessage [−][src]
pub struct ChildMessage(_);Expand description
A message is received from a child (i)frame or a parent window. MDN documentation
Methods from Deref<Target = MessageEvent>
Getter for the data field of this object.
This API requires the following crate features to be activated: MessageEvent
Getter for the origin field of this object.
This API requires the following crate features to be activated: MessageEvent
Getter for the lastEventId field of this object.
This API requires the following crate features to be activated: MessageEvent
Getter for the source field of this object.
This API requires the following crate features to be activated: MessageEvent
Getter for the ports field of this object.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
pub fn init_message_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool
)
pub fn init_message_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool
)
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, Window
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, Window