Struct augdom::event::CompositionEndBuilder [−][src]
pub struct CompositionEndBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = CompositionEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: CompositionEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: CompositionEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: CompositionEventInit
Change the detail field of this object.
This API requires the following crate features to be activated: CompositionEventInit
Change the view field of this object.
This API requires the following crate features to be activated: CompositionEventInit, Window
Change the data field of this object.
This API requires the following crate features to be activated: CompositionEventInit