Struct augdom::event::CompositionStart [−][src]
pub struct CompositionStart(_);Expand description
The composition of a passage of text is prepared (similar to keydown for a keyboard input, but works with other inputs such as speech recognition). MDN documentation
Methods from Deref<Target = CompositionEvent>
Getter for the data field of this object.
This API requires the following crate features to be activated: CompositionEvent
Getter for the locale field of this object.
This API requires the following crate features to be activated: CompositionEvent
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
pub fn init_composition_event_with_can_bubble_arg(
&self,
type_arg: &str,
can_bubble_arg: bool
)
pub fn init_composition_event_with_can_bubble_arg(
&self,
type_arg: &str,
can_bubble_arg: bool
)
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool
)
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool
)
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window