Struct augdom::event::FocusInBuilder [−][src]
pub struct FocusInBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = FocusEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: FocusEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: FocusEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: FocusEventInit
Change the detail field of this object.
This API requires the following crate features to be activated: FocusEventInit
Change the view field of this object.
This API requires the following crate features to be activated: FocusEventInit, Window
Change the relatedTarget field of this object.
This API requires the following crate features to be activated: EventTarget, FocusEventInit