Struct augdom::event::GamepadDisconnectedBuilder [−][src]
pub struct GamepadDisconnectedBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = GamepadEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: GamepadEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: GamepadEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: GamepadEventInit