Struct augdom::event::HashChange [−][src]
pub struct HashChange(_);Expand description
The fragment identifier of the URL has changed (the part of the URL after the #). MDN documentation
Methods from Deref<Target = HashChangeEvent>
Getter for the oldURL field of this object.
This API requires the following crate features to be activated: HashChangeEvent
Getter for the newURL field of this object.
This API requires the following crate features to be activated: HashChangeEvent
The initHashChangeEvent() method.
This API requires the following crate features to be activated: HashChangeEvent
pub fn init_hash_change_event_with_can_bubble_arg(
&self,
type_arg: &str,
can_bubble_arg: bool
)
pub fn init_hash_change_event_with_can_bubble_arg(
&self,
type_arg: &str,
can_bubble_arg: bool
)
The initHashChangeEvent() method.
This API requires the following crate features to be activated: HashChangeEvent
pub fn init_hash_change_event_with_can_bubble_arg_and_cancelable_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool
)
pub fn init_hash_change_event_with_can_bubble_arg_and_cancelable_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool
)
The initHashChangeEvent() method.
This API requires the following crate features to be activated: HashChangeEvent
The initHashChangeEvent() method.
This API requires the following crate features to be activated: HashChangeEvent
The initHashChangeEvent() method.
This API requires the following crate features to be activated: HashChangeEvent