Struct augdom::event::HashChangeBuilder [−][src]
pub struct HashChangeBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = HashChangeEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: HashChangeEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: HashChangeEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: HashChangeEventInit
Change the newURL field of this object.
This API requires the following crate features to be activated: HashChangeEventInit
Change the oldURL field of this object.
This API requires the following crate features to be activated: HashChangeEventInit