Struct augdom::event::LoadStartBuilder [−][src]
pub struct LoadStartBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = ProgressEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: ProgressEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: ProgressEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: ProgressEventInit
Change the lengthComputable field of this object.
This API requires the following crate features to be activated: ProgressEventInit
Change the loaded field of this object.
This API requires the following crate features to be activated: ProgressEventInit
Change the total field of this object.
This API requires the following crate features to be activated: ProgressEventInit