Struct augdom::event::LostPointerCapture [−][src]
pub struct LostPointerCapture(_);Expand description
Element lost pointer capture. MDN documentation
Methods from Deref<Target = PointerEvent>
Getter for the pointerId field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the width field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the height field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the pressure field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the tangentialPressure field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the tiltX field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the tiltY field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the twist field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the pointerType field of this object.
This API requires the following crate features to be activated: PointerEvent
Getter for the isPrimary field of this object.
This API requires the following crate features to be activated: PointerEvent
The getCoalescedEvents() method.
This API requires the following crate features to be activated: PointerEvent