Struct augdom::event::MessageErrorBuilder [−][src]
pub struct MessageErrorBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = MessageEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the data field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the lastEventId field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the origin field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the ports field of this object.
This API requires the following crate features to be activated: MessageEventInit
Change the source field of this object.
This API requires the following crate features to be activated: MessageEventInit