Struct augdom::event::PageShowBuilder [−][src]
pub struct PageShowBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = PageTransitionEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: PageTransitionEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: PageTransitionEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: PageTransitionEventInit
Change the inFrameSwap field of this object.
This API requires the following crate features to be activated: PageTransitionEventInit
Change the persisted field of this object.
This API requires the following crate features to be activated: PageTransitionEventInit