Struct augdom::event::ProgressError [−][src]
pub struct ProgressError(_);Expand description
Progression has failed. MDN documentation
Methods from Deref<Target = ProgressEvent>
Getter for the lengthComputable field of this object.
This API requires the following crate features to be activated: ProgressEvent
Getter for the loaded field of this object.
This API requires the following crate features to be activated: ProgressEvent
Getter for the total field of this object.
This API requires the following crate features to be activated: ProgressEvent