Struct augdom::event::ResourceErrorBuilder [−][src]
pub struct ResourceErrorBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = UiEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: UiEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: UiEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: UiEventInit
Change the detail field of this object.
This API requires the following crate features to be activated: UiEventInit
Change the view field of this object.
This API requires the following crate features to be activated: UiEventInit, Window