Struct augdom::event::SpeechRecognitionNoMatchBuilder [−][src]
pub struct SpeechRecognitionNoMatchBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = SpeechRecognitionEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEventInit
Change the emma field of this object.
This API requires the following crate features to be activated: Document, SpeechRecognitionEventInit
Change the interpretation field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEventInit
Change the resultIndex field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEventInit