Struct augdom::event::SpeechRecognitionResult [−][src]
pub struct SpeechRecognitionResult(_);Expand description
The speech recognition service returns a result — a word or phrase has been positively recognized and this has been communicated back to the app. MDN documentation
Methods from Deref<Target = SpeechRecognitionEvent>
Getter for the resultIndex field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEvent
Getter for the interpretation field of this object.
This API requires the following crate features to be activated: SpeechRecognitionEvent
Getter for the emma field of this object.
This API requires the following crate features to be activated: Document, SpeechRecognitionEvent