Struct augdom::event::SpeechRecognitionStart [−][src]
pub struct SpeechRecognitionStart(_);Expand description
The speech recognition service has begun listening to incoming audio with intent to recognize grammars associated with the current SpeechRecognition. MDN documentation