Struct augdom::event::StorageBuilder [−][src]
pub struct StorageBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = StorageEventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the composed field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the key field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the newValue field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the oldValue field of this object.
This API requires the following crate features to be activated: StorageEventInit
Change the url field of this object.
This API requires the following crate features to be activated: StorageEventInit