Struct augdom::event::TransactionVersionChangeBuilder [−][src]
pub struct TransactionVersionChangeBuilder(_);Expand description
A builder for events.
Methods from Deref<Target = EventInit>
Change the bubbles field of this object.
This API requires the following crate features to be activated: EventInit
Change the cancelable field of this object.
This API requires the following crate features to be activated: EventInit