The data of a node in the virtual DOM tree.
Fields of Elem
The element’s attributes.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
impl<T> AsContext for T where
T: 'static + Debug,
Call op within the context of a Layer containing self.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.