pub struct Found<'find, 'pat, 'node, N> { /* fields omitted */ }
The final description of a subtree query. The methods on this struct
execute the underlying search and return the results in various forms.
impl<'find, 'pat, 'node, N> Found<'find, 'pat, 'node, N> where
N: Dom + Debug,
Wrap the query in a MutationObserver with async methods that resolve
once the wrapped query could succeed or a 1 second timeout has expired.
Execute the query and return the only matching node in the queried
subtree.
If more than one matching node is found.
Execute the query and return a Vec of matching nodes in the queried
subtree.
Formats the value using the given formatter. Read more
impl<'find, 'pat, 'node, N> Send for Found<'find, 'pat, 'node, N> where
N: Sync,
impl<'find, 'pat, 'node, N> Sync for Found<'find, 'pat, 'node, N> where
N: Sync,
impl<'find, 'pat, 'node, N> Unpin for Found<'find, 'pat, 'node, N> where
'node: 'find,
impl<T> Any for T where
T: 'static + ?Sized,
impl<T> AsContext for T where
T: 'static + Debug,
Call op within the context of a Layer containing self.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.