pub struct Until<'query, 'find, 'pat, 'node, N> { /* fields omitted */ }
A query which resolves asynchronously
impl<'query, 'find, 'pat, 'node, N> Until<'query, 'find, 'pat, 'node, N> where
N: Dom + Debug,
Wait until the query can succeed then return the only matching node
in the queried subtree.
If more than one matching node is found.
Wait until the query can succeed then return a Vec of matching nodes
in the queried subtree.
impl<'query, 'find, 'pat, 'node, N: Debug> Debug for Until<'query, 'find, 'pat, 'node, N>
Formats the value using the given formatter. Read more
impl<'query, 'find, 'pat, 'node, N> Send for Until<'query, 'find, 'pat, 'node, N> where
N: Sync,
impl<'query, 'find, 'pat, 'node, N> Sync for Until<'query, 'find, 'pat, 'node, N> where
N: Sync,
impl<'query, 'find, 'pat, 'node, N> Unpin for Until<'query, 'find, 'pat, 'node, N> where
'find: 'query,
'node: 'query,
'pat: 'query,
impl<T> Any for T where
T: 'static + ?Sized,
impl<T> AsContext for T where
T: 'static + Debug,
Call op within the context of a Layer containing self.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.