pub struct Callback { /* fields omitted */ }
A dynamically-allocated closure that is callable from JavaScript.
Allocate a new JS-compatible callback.
Returns an reference to the underlying JS function. If the reference is
used after this Callback is dropped it will panic.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.